pub struct Check {
pub index: usize,
pub category: CheckCategory,
pub locator: Option<String>,
pub context: Option<String>,
pub success: bool,
pub severity: CheckSeverity,
pub errors: Option<ErrorKind>,
pub uri: Option<String>,
pub message: String,
/* private fields */
}Expand description
Data structure for holding the result of a schema validation check
Fields
index: usizePosition of this issue in rendered output
category: CheckCategoryCheck category
locator: Option<String>Unified issue location for checks (prose location or schema path)
context: Option<String>Textual context of check (e.g., paragraph where prose issues were found)
success: boolWhether or not the check was successful
severity: CheckSeveritySeverity of the check result
errors: Option<ErrorKind>Errors and issues found during check
uri: Option<String>Path of file being validated
message: StringMessage related to or description of validation issue (e.g., key name of invalid value, result of validation, etc.)
Implementations
Sourceimpl Check
impl Check
Sourcepub fn init() -> CheckBuilder
pub fn init() -> CheckBuilder
Create an instance of Check using the builder syntax
Sourceimpl Check
impl Check
Sourcepub fn count_validation_errors(kind: &ValidationErrorsKind) -> usize
pub fn count_validation_errors(kind: &ValidationErrorsKind) -> usize
Recursively count validation errors from a given ValidationErrorsKind
Sourcepub fn is_failure(&self) -> bool
pub fn is_failure(&self) -> bool
Returns whether this check represents a failure (not successful and severity warrants failure)
Sourcepub fn is_visible_at(level: Option<u8>) -> impl Fn(&Check) -> bool
pub fn is_visible_at(level: Option<u8>) -> impl Fn(&Check) -> bool
Returns a function that filters checks based on the given log level threshold
Sourcepub fn issue_count(&self) -> usize
pub fn issue_count(&self) -> usize
Returns the number of errors
Sourcepub fn with_context(self, value: String) -> Self
pub fn with_context(self, value: String) -> Self
Returns a new LinkCheckResult with the given context
Sourcepub fn with_index(self, value: usize) -> Self
pub fn with_index(self, value: usize) -> Self
Returns a new LinkCheckResult with the given index
Sourcepub fn with_locator(self, value: Option<String>) -> Self
pub fn with_locator(self, value: Option<String>) -> Self
Returns a new LinkCheckResult with the given locator