DocumentTarget

Trait DocumentTarget 

pub trait DocumentTarget {
    // Required methods
    fn locator(&self) -> String;
    fn source_text(&self) -> String;
    fn query(&self) -> DocumentQuery;
}
Trait for findings that can identify their target within a source document.

Required Methods

fn locator(&self) -> String

Return a string indicating where the issue is located, for use in check titles, summaries, etc.

fn source_text(&self) -> String

Return source text

fn query(&self) -> DocumentQuery

Return format-neutral criteria for resolving the finding in its original document.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors