pub enum Location {
Simple(String),
Detailed {
scheme: Scheme,
uri: String,
},
}Expand description
Abstraction for file and folder locations that can be local (e.g., file:///path/to/project) or remote (e.g., https://gitlab.com/project)
Variants
Simple(String)
Just the URI string (assumes remote location)
Detailed
Location defined by URI and scheme - intended for use with remote or local locations
Implementations
Sourceimpl Location
impl Location
Sourcepub fn hash(&self) -> String
pub fn hash(&self) -> String
Get associated location hash
Useful for standardizing file path handling across local and remote contexts
Example
use acorn::Location;
let location = Location::Simple("https://code.ornl.gov/research-enablement/buckets/nssd".to_string());
assert_eq!(location.hash(), "code_ornl_gov_research-enablement_buckets_nssd");Sourcepub fn scheme(&self) -> Scheme
pub fn scheme(&self) -> Scheme
Get associated location value scheme (e.g., https, file, etc.)
Example
use acorn::{Location, Scheme};
let location = Location::Simple("https://code.ornl.gov/research-enablement/buckets/nssd".to_string());
assert_eq!(location.scheme(), Scheme::HTTPS);
let location = Location::Simple("file://localhost/buckets/nssd".to_string());
assert_eq!(location.scheme(), Scheme::File);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Location
impl<'de> Deserialize<'de> for Location
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,