pub enum Repository {
Git {
location: Location,
},
GitHub {
location: Location,
},
GitLab {
id: Option<u64>,
location: Location,
},
HuggingFace {
location: Location,
},
}Expand description
Git hosting repository data
Variants
Git
Generic Git repository
Note
This repository type should be used for local and offline repositories. Having the associated data be version controlled by Git is recommended, but not required.
GitHub
GitLab
Fields
id: Option<u64>Integer ID of GitLab project
See https://docs.gitlab.com/api/projects/#get-a-single-project for more information
HuggingFace
Hugging Face
See https://huggingface.co/docs/hub/repositories-getting-started
Implementations
Sourceimpl Repository
impl Repository
Sourcepub const fn is_git_hub(&self) -> bool
pub const fn is_git_hub(&self) -> bool
Returns true if the enum is Repository::GitHub otherwise false
Sourcepub const fn is_git_lab(&self) -> bool
pub const fn is_git_lab(&self) -> bool
Returns true if the enum is Repository::GitLab otherwise false
Sourcepub const fn is_hugging_face(&self) -> bool
pub const fn is_hugging_face(&self) -> bool
Returns true if the enum is Repository::HuggingFace otherwise false
Sourceimpl Repository
impl Repository
Sourcepub fn from_remote(value: &str, domain: &str) -> Option<Self>
pub fn from_remote(value: &str, domain: &str) -> Option<Self>
Classify a remote repository URL using its overt provider domain
Sourcepub fn domain(&self) -> Option<String>
pub fn domain(&self) -> Option<String>
Get repository domain (e.g., “github.com” or “code.ornl.gov”)
Sourcepub fn is_local(&self) -> bool
pub fn is_local(&self) -> bool
Return whether or not the associated URI for a repository is local (e.g., has “file” scheme)
Sourcepub async fn latest_release(self) -> Option<Release>
pub async fn latest_release(self) -> Option<Release>
Get metadata for latest release of a Gitlab or GitHub repository
Sourcepub fn project_path(&self) -> Option<String>
pub fn project_path(&self) -> Option<String>
Return the provider-native repository path or identifier.