Module for interacting with GitLab API
Modules
- bot
- GitLab bot implementation
Structs
- Error
Response - GitLab API error response
- Event
Details - GitLab event details
- Group
Details - Runner group details
- Note
Metadata - GitLab API response for creating a merge request comment
- Options
- Options for GitLab API requests
- Options
Builder - Use builder syntax to set the inputs and finish with
build(). - Programming
Language Details - Language metadata details from GitLab languages YAML file
- Programming
Language Metadata - Normalized programming language metadata with explicit language name
- Programming
Language UseMetadata - Programming language usage entry for a project
- Programming
Language UseResponse - Parsed response for GitLab project language usage
- Programming
Languages Response - Parsed response for GitLab language metadata
- Push
Data - Push data details for a GitLab event
- Runner
Creation Response - GitLab API response for creating a runner
- Runner
Group Access Level - Access level entry for branch protection settings
- Runner
Group Branch Protection Defaults - Runner group branch protection defaults
- Runner
Metadata - GitLab API response for runner details
- Runner
Metadata Builder - Use builder syntax to set the inputs and finish with
build(). - Runner
Scope - Runner scope details for project or group entries
- Tree
Entry - Struct for GitLab tree entry
- Tree
Response - GitLab tree response normalized to blob file paths
- User
Metadata - User details
Enums
- Access
Level - Access level of the runner
- Emoji
- GitLab emoji shortcodes
- Event
Action - GitLab event action name
- Event
Filter Key - Event filter keys used to filter events for a given project
- Group
Visibility - Group visibility level
- Order
ByValue - Valid values for pagination order_by field
- Pagination
Key - Pagination list parameters
- Sort
Value - Valid values for pagination sort field
- Target
Type - GitLab event target type
Traits
- Create
- Trait for adding creation and registration functionality (e.g., runners, issues, merge requests, etc.)
Functions
- create_
runner - Create a new runner using project or group identifier
- events
- Get events for a project
- groups
- Get descendant groups of a group by identifier
- language_
use - Get programming languages used by a GitLab project
- languages
- Download programming language metadata from GitLab linguist source file
- merge_
request_ note - Add a note (comment) to a merge request using project identifier and merge request IID
- runner
- Get runner details by identifier
- runners
- Get runners visible to user associated with given token
Type Aliases
- Events
Response - Type for GitLab events response
- Groups
Response - Type for GitLab API descendent groups response
- Programming
Language Entries - Type for GitLab programming language entries
- Programming
Language UseEntries - Type for GitLab project programming language usage entries
- Runners
Response - Type for GitLab API all runners response