pub struct Options {
pub token: String,
pub body: Option<String>,
pub domain: String,
pub identifier: Option<String>,
pub path: Option<String>,
pub page: u32,
pub internal_identifier: Option<String>,
pub runner_metadata: RunnerMetadata,
pub custom_params: Vec<Param>,
}Expand description
Options for GitLab API requests
Fields
token: StringAuthentication token
body: Option<String>Request body payload
domain: StringGitLab domain (defaults to gitlab.com)
identifier: Option<String>Project or group identifier
path: Option<String>Repository path used for tree requests
page: u32Page number to retrieve
internal_identifier: Option<String>Internal resource identifier (e.g., merge request IID)
runner_metadata: RunnerMetadataGitLab runner metadata necessary for creation
custom_params: Vec<Param>Custom API parameters to include in every request
Implementations
Sourceimpl Options
impl Options
Sourcepub fn with_token(token: impl Into<String>) -> OptionsBuilder
pub fn with_token(token: impl Into<String>) -> OptionsBuilder
Create an instance of Options using the builder syntax
Sourceimpl Options
impl Options
Sourcepub fn with_path(self, value: impl Into<String>) -> Self
pub fn with_path(self, value: impl Into<String>) -> Self
Return a copy of options with repository path set
Sourcepub fn with_runner(self, metadata: RunnerMetadata) -> Self
pub fn with_runner(self, metadata: RunnerMetadata) -> Self
Return a copy of options with runner metadata set