pub struct RunnerMetadata {Show 25 fields
pub identifier: Option<u64>,
pub active: bool,
pub online: Option<bool>,
pub paused: bool,
pub run_untagged: bool,
pub shared: bool,
pub architecture: Option<String>,
pub description: Option<String>,
pub ip_address: Option<String>,
pub runner_type: RunnerType,
pub created_by: Option<UserMetadata>,
pub created_at: Option<String>,
pub contacted_at: Option<String>,
pub maintenance_note: Option<String>,
pub name: Option<String>,
pub status: Option<RunnerStatus>,
pub job_execution_status: Option<String>,
pub platform: Option<String>,
pub projects: Option<Vec<RunnerScope>>,
pub groups: Option<Vec<RunnerScope>>,
pub revision: Option<String>,
pub tags: Option<Vec<String>>,
pub version: Option<String>,
pub access_level: Option<AccessLevel>,
pub maximum_timeout: Option<u64>,
}Expand description
GitLab API response for runner details
Example JSON response
{
"active": true,
"paused": false,
"architecture": null,
"description": "test-1-20150125",
"id": 6,
"ip_address": "",
"is_shared": false,
"runner_type": "project_type",
"contacted_at": "2016-01-25T16:39:48.066Z",
"maintenance_note": null,
"name": null,
"online": true,
"status": "online",
"platform": null,
"projects": [
{
"id": 1,
"name": "GitLab Community Edition",
"name_with_namespace": "GitLab.org / GitLab Community Edition",
"path": "gitlab-foss",
"path_with_namespace": "gitlab-org/gitlab-foss"
}
],
"revision": null,
"tag_list": [
"ruby",
"mysql"
],
"version": null,
"access_level": "ref_protected",
"maximum_timeout": 3600
}Fields
identifier: Option<u64>Numeric ID of the runner
active: boolWhether the runner is active
online: Option<bool>Whether the runner is online
Apparently, GitLab’s API may return null for this field when the runner has never been contacted, so we use an Option<bool> to capture that possibility.
paused: boolWhether the runner is paused
run_untagged: boolWhether the runner runs untagged jobs
Whether the runner is shared
architecture: Option<String>CPU architecture reported by the runner
description: Option<String>Runner description
ip_address: Option<String>Runner IP address
runner_type: RunnerTypeType of runner (for example, project_type)
created_by: Option<UserMetadata>Created by user
created_at: Option<String>Created timestamp in ISO-8601 format
contacted_at: Option<String>Last contact timestamp in ISO-8601 format
maintenance_note: Option<String>Optional maintenance note
name: Option<String>Optional display name
status: Option<RunnerStatus>Current runner status
job_execution_status: Option<String>Current job execution status
platform: Option<String>Optional platform string
projects: Option<Vec<RunnerScope>>Projects associated with this runner
groups: Option<Vec<RunnerScope>>Groups associated with this runner
revision: Option<String>Optional Git revision for the runner version
Runner tags
version: Option<String>Optional runner version
access_level: Option<AccessLevel>Access level for this runner
maximum_timeout: Option<u64>Maximum timeout in seconds
Implementations
Sourceimpl RunnerMetadata
impl RunnerMetadata
Sourcepub fn init() -> RunnerMetadataBuilder
pub fn init() -> RunnerMetadataBuilder
Create an instance of RunnerMetadata using the builder syntax
Sourceimpl RunnerMetadata
impl RunnerMetadata
Sourcepub fn is_available(&self) -> bool
pub fn is_available(&self) -> bool
Whether the runner is active and online
Sourcepub fn with_identifier(self, value: u64) -> Self
pub fn with_identifier(self, value: u64) -> Self
Return a copy of runner metadata with project or group identifier set