Create

Trait Create 

pub trait Create {
    // Provided methods
    fn create(_options: &Options) -> ApiResult<Self>
       where Self: Sized { ... }
    fn register(self) -> ApiResult<Self>
       where Self: Sized { ... }
}
Trait for adding creation and registration functionality (e.g., runners, issues, merge requests, etc.)

Provided Methods

fn create(_options: &Options) -> ApiResult<Self>
where Self: Sized,

Create a new instance of the struct with default values

fn register(self) -> ApiResult<Self>
where Self: Sized,

Register a new instance of the struct with specified values

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors