pub struct RepositoryResolution<T> { /* private fields */ }Expand description
A repository-backed value together with its requested and resolved identifiers.
Implementations
Sourceimpl<T> RepositoryResolution<T>
impl<T> RepositoryResolution<T>
Sourcepub fn new(
requested: impl Into<String>,
resolved: impl Into<String>,
value: T,
) -> Self
pub fn new( requested: impl Into<String>, resolved: impl Into<String>, value: T, ) -> Self
Create a repository resolution from requested and resolved identifiers.
Sourcepub fn direct(identifier: impl Into<String>, value: T) -> Self
pub fn direct(identifier: impl Into<String>, value: T) -> Self
Create a direct repository resolution from one identifier.
Sourcepub fn is_fallback(&self) -> bool
pub fn is_fallback(&self) -> bool
Return whether fallback discovery selected a different repository.
Sourcepub fn resolved(&self) -> &str
pub fn resolved(&self) -> &str
Return the repository identifier that supplied the resolved value.
Sourcepub fn map<U>(self, transform: impl FnOnce(T) -> U) -> RepositoryResolution<U>
pub fn map<U>(self, transform: impl FnOnce(T) -> U) -> RepositoryResolution<U>
Transform the resolved value while preserving repository identity.
Sourcepub fn try_map<U, E>(
self,
transform: impl FnOnce(T) -> Result<U, E>,
) -> Result<RepositoryResolution<U>, E>
pub fn try_map<U, E>( self, transform: impl FnOnce(T) -> Result<U, E>, ) -> Result<RepositoryResolution<U>, E>
Try to transform the resolved value while preserving repository identity.
Sourcepub fn into_parts(self) -> (String, String, T)
pub fn into_parts(self) -> (String, String, T)
Consume the resolution into its identifiers and value.