pub struct Options {
pub token: String,
pub body: Option<String>,
pub domain: String,
pub identifier: Option<String>,
pub after: Option<String>,
pub limit: Option<u32>,
pub order: Option<String>,
pub model: Option<String>,
pub custom_params: Vec<Param>,
}Expand description
OpenAI API options
Configuration options used across OpenAI API operations.
Fields
token: StringBearer token for authentication
body: Option<String>Request body payload for POST requests
domain: StringOpenAI API domain (defaults to api.openai.com)
identifier: Option<String>Optional model identifier for model retrieval
after: Option<String>Optional cursor for paginated list APIs
limit: Option<u32>Optional page size for list APIs
order: Option<String>Optional ordering value for list APIs (for example, asc or desc)
model: Option<String>Optional model filter used by selected list APIs
custom_params: Vec<Param>Custom API parameters to include in every request
Implementations
Sourceimpl Options
impl Options
Sourcepub fn with_token(token: impl Into<String>) -> OptionsBuilder
pub fn with_token(token: impl Into<String>) -> OptionsBuilder
Create an instance of Options using the builder syntax
Sourceimpl Options
impl Options
Sourcepub fn with_after(self, value: impl Into<String>) -> Self
pub fn with_after(self, value: impl Into<String>) -> Self
Return a copy of options with list cursor set
Sourcepub fn with_limit(self, value: u32) -> Self
pub fn with_limit(self, value: u32) -> Self
Return a copy of options with page size set
Sourcepub fn with_model(self, value: impl Into<String>) -> Self
pub fn with_model(self, value: impl Into<String>) -> Self
Return a copy of options with model filter set
Sourcepub fn with_order(self, value: impl Into<String>) -> Self
pub fn with_order(self, value: impl Into<String>) -> Self
Return a copy of options with order value set