pub struct LicenseMetadata {
pub license_id: String,
pub name: String,
pub details_url: String,
pub reference: String,
pub reference_number: u32,
pub see_also: Vec<String>,
pub is_deprecated: bool,
pub is_free_software: bool,
pub is_osi: bool,
}Expand description
SPDX license metadata
Fields
license_id: StringSPDX license identifier
name: StringName of the license
details_url: StringURL to a JSON file containing the license detailed information
reference: StringReference to the HTML format for the license file
reference_number: u32Deprecated - this field is generated and is no longer in use
see_also: Vec<String>Cross reference URL(s) pointing to additional copies of the license
is_deprecated: boolSpecifies whether the license is deprecated
Note
This isn’t actually the best name for this particular field
is_free_software: boolSpecifies whether the License is listed as free by the Free Software Foundation (FSF)
See https://www.fsf.org/licensing/compliance for more information
is_osi: boolSpecifies whether the license is approved by the Open Source Initiative (OSI)
Implementations
Sourceimpl LicenseMetadata
impl LicenseMetadata
Sourcepub fn is_open_source(&self) -> bool
pub fn is_open_source(&self) -> bool
Check if the license is OSI approved