pub struct Param {
pub style: ParamStyle,
pub name: String,
pub values: Vec<(Option<String>, Option<String>)>,
pub required: bool,
}Expand description
Describes a parameter (path, query, header, etc.) for an API resource
Fields
style: ParamStyleThe type/location of the parameter
name: StringThe name of the parameter (e.g., “q”, “fl”, etc.)
values: Vec<(Option<String>, Option<String>)>Value(s) of the parameter
required: boolWhether or not the parameter is required
Implementations
Sourceimpl Param
impl Param
Sourcepub fn of_type(style: ParamStyle) -> ParamBuilder
pub fn of_type(style: ParamStyle) -> ParamBuilder
Create an instance of Param using the builder syntax
Sourceimpl Param
impl Param
Sourcepub fn is_query(&self) -> bool
pub fn is_query(&self) -> bool
Check if this parameter is a query parameter (either a query pair, boosted query field, or field list)
Sourcepub fn is_template(&self) -> bool
pub fn is_template(&self) -> bool
Check if this parameter is a template value
Sourcepub fn to_query_string<Q: QueryField + ValueValidator, F: QueryField>(
params: Vec<Param>,
) -> String
pub fn to_query_string<Q: QueryField + ValueValidator, F: QueryField>( params: Vec<Param>, ) -> String
Convert a list of params to a query string
Sourcepub fn from_query_pair(key: &str, pairs: Vec<(&str, &str)>) -> Self
pub fn from_query_pair(key: &str, pairs: Vec<(&str, &str)>) -> Self
Create a query pair parameter with key-value pairs
Example
let param = Param::from_query_pair("q", vec![("given-names", "Jason"), ("family-name", "Wohlgemuth")]);
let rendered = param.to_string::<orcid::SearchField, orcid::OutputColumn>();
let expected = "q=given-names:Jason+AND+family-name:Wohlgemuth";
assert_eq!(rendered, expected);Sourcepub fn from_field_list(key: &str, fields: Vec<&str>) -> Self
pub fn from_field_list(key: &str, fields: Vec<&str>) -> Self
Create a field list parameter with a list of field names
Sourcepub fn from_query_field(key: &str, fields: Vec<&str>) -> Self
pub fn from_query_field(key: &str, fields: Vec<&str>) -> Self
Create a boosted query field parameter with a list of field names
Sourcepub fn to_string<Q: QueryField + ValueValidator, F: QueryField>(&self) -> String
pub fn to_string<Q: QueryField + ValueValidator, F: QueryField>(&self) -> String
Render this parameter to a query string using the provided field types.
Qis used for query pairs and boosted query fields and must support validation (Validatetrait).Fis used for field lists (e.g., output columns).