Configuration

Trait Configuration 

pub trait Configuration {
    // Required methods
    fn from_env() -> Self;
    fn with_body(self, value: impl Into<String>) -> Self;
    fn with_domain(self, value: impl Into<String>) -> Self;
    fn with_identifier(self, value: impl Into<String>) -> Self;
    fn token(&self) -> &str;
    fn domain(&self) -> &str;
    fn identifier(&self) -> Option<&str>;
    fn with_params(self, params: Vec<Param>) -> Self;
    fn params(&self) -> &[Param];
}
Trait to standardize configuration loading from environment variables and modification with new values

Required Methods

fn from_env() -> Self

Populate values from environment (e.g., .env file or environment variables)

fn with_body(self, value: impl Into<String>) -> Self

Return a copy of this configuration with the specified request body payload set

fn with_domain(self, value: impl Into<String>) -> Self

Return a copy of this configuration with the specified domain set

fn with_identifier(self, value: impl Into<String>) -> Self

Return a copy of this configuration with the specified resource identifier set

fn token(&self) -> &str

Return the authentication token

fn domain(&self) -> &str

Return the API domain

fn identifier(&self) -> Option<&str>

Return the optional resource identifier

fn with_params(self, params: Vec<Param>) -> Self

Return a copy of this configuration with custom API parameters set. These are appended to internally-constructed parameters before each request.

fn params(&self) -> &[Param]

Return any custom API parameters

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Configuration for acorn::io::api::citeas::Options

Source

impl Configuration for acorn::io::api::gitlab::Options

Source

impl Configuration for acorn::io::api::openai::Options

Source

impl Configuration for acorn::io::api::orcid::Options

Source

impl Configuration for acorn::io::api::raid::Options

Source

impl Configuration for acorn::io::api::ror::Options