pub struct ApplicationConfiguration {
pub cst: Option<CstRootNode>,
pub buckets: Option<Vec<Bucket>>,
pub config: Option<Config>,
pub endpoints: Option<Vec<Endpoint>>,
pub models: Option<Vec<ModelEntry>>,
pub runners: Option<Vec<RunnerDetails>>,
pub whitelist: Option<WhitelistLookup>,
}Expand description
Struct for application configuration
Example .acorn configuration file
{
"buckets": [
{
"name": "big-science",
"repository": {
"provider": "github",
"uri": "https://github.com/username/example"
}
},
{
"name": "does-it-scale",
"repository": {
"provider": "gitlab",
"id": 12345,
"uri": "https://gitlab.com/username/example"
}
}
],
"models": [
"meta-llama/Llama-2-7b-hf",
"microsoft/phi-2"
],
"runners": [
{
"name": "ACORN Runner B",
"repository": {
"provider": "gitlab",
"id": 24758,
"uri": "https://code.ornl.gov/research-enablement"
},
"type": "group",
"runUntagged": true
}
]
}Fields
cst: Option<CstRootNode>CST root for JSONC comment-preserving round-trips
buckets: Option<Vec<Bucket>>List of buckets
config: Option<Config>Synchronization targets for llama-swap, OpenCode, VS Code, and Goose
endpoints: Option<Vec<Endpoint>>List of endpoints
models: Option<Vec<ModelEntry>>List of models to download — bare IDs/paths or detailed download entries
runners: Option<Vec<RunnerDetails>>List of runners
whitelist: Option<WhitelistLookup>Lookup object for whitelisted downloadable items
Implementations
Sourceimpl ApplicationConfiguration
impl ApplicationConfiguration
Sourcepub fn load(path: &Option<PathBuf>) -> ApiResult<Self>
pub fn load(path: &Option<PathBuf>) -> ApiResult<Self>
Load explicit or discovered application configuration, rejecting a missing explicit path.
Sourcepub fn resolve_sync_config(&self, overrides: Config) -> Config
pub fn resolve_sync_config(&self, overrides: Config) -> Config
Merge configured synchronization settings with runtime overrides.
Sourcepub fn model_entries_and_whitelist(
&self,
) -> (Vec<ModelEntry>, Option<OneOrMany<String>>)
pub fn model_entries_and_whitelist( &self, ) -> (Vec<ModelEntry>, Option<OneOrMany<String>>)
Return configured model entries and their download whitelist.
Sourcepub fn sync(&self, options: Options<'_>) -> ApiResult<()>
pub fn sync(&self, options: Options<'_>) -> ApiResult<()>
Synchronize selected model entries with configured local inference targets.
Sourcepub fn sync_and_update(
&self,
path: &Option<PathBuf>,
options: Options<'_>,
) -> ApiResult<()>
pub fn sync_and_update( &self, path: &Option<PathBuf>, options: Options<'_>, ) -> ApiResult<()>
Synchronize selected models and add their unique identifiers to ACORN configuration.
Sourcepub fn resolve(path: &Option<PathBuf>) -> Option<PathBuf>
pub fn resolve(path: &Option<PathBuf>) -> Option<PathBuf>
Resolve application configuration path
Sourcepub fn resolve_in(path: &Option<PathBuf>, directory: &Path) -> Option<PathBuf>
pub fn resolve_in(path: &Option<PathBuf>, directory: &Path) -> Option<PathBuf>
Resolve an application configuration path relative to an explicit directory.
Sourcepub fn parse(content: impl AsRef<str>) -> ApiResult<Self>
pub fn parse(content: impl AsRef<str>) -> ApiResult<Self>
Parse ACORN configuration in JSON, JSONC, or YAML format
Note
If the content is valid JSON, it is parsed as JSON.
If it is not valid JSON but starts with { or [, it is first attempted to be parsed as JSON, and if that fails, it is attempted to be parsed as YAML.
If the content does not start with { or [, it is parsed as YAML.