pub struct ModelEntryOptions {
pub name: String,
pub source: Repository,
pub revision: Option<String>,
pub auth: Option<AuthenticationRequirement>,
pub filter: Option<Vec<String>>,
pub ignore: Option<Vec<String>>,
pub quantization: Option<OneOrMany<Quantization>>,
pub gpu_memory: Option<Memory>,
pub copy: Option<bool>,
pub symlink: Option<bool>,
}Expand description
Detailed model download entry for use in ApplicationConfiguration.models
Fields
name: StringUser-facing model name
source: RepositoryModel weight source (local path, URL, or Hugging Face repository)
revision: Option<String>Optional repository revision, branch, or tag to resolve
auth: Option<AuthenticationRequirement>Authentication requirement for this model source
filter: Option<Vec<String>>Regex pattern(s) used to include model files for this entry
ignore: Option<Vec<String>>Regex pattern(s) used to exclude model files for this entry
quantization: Option<OneOrMany<Quantization>>Ordered exact GGUF quantization allowlist
gpu_memory: Option<Memory>Maximum GPU memory available for model weights
copy: Option<bool>Copy local model files into the model directory instead of referencing in place
symlink: Option<bool>Symlink local model files into the model directory instead of referencing in place
Implementations
Sourceimpl ModelEntryOptions
impl ModelEntryOptions
Sourcepub fn init() -> ModelEntryOptionsBuilder
pub fn init() -> ModelEntryOptionsBuilder
Create an instance of ModelEntryOptions using the builder syntax