Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 22 variants SqliteFailure(Error, Option<String>), SqliteSingleThreadedMode, FromSqlConversionFailure(usize, Type, Box<dyn Error + Send + Sync>), IntegralValueOutOfRange(usize, i64), Utf8Error(usize, Utf8Error), NulError(NulError), InvalidParameterName(String), InvalidPath(PathBuf), ExecuteReturnedResults, QueryReturnedNoRows, QueryReturnedMoreThanOneRow, InvalidColumnIndex(usize), InvalidColumnName(String), InvalidColumnType(usize, String, Type), StatementChangedRows(usize), ToSqlConversionFailure(Box<dyn Error + Send + Sync>), InvalidQuery, UnwindingPanic, MultipleStatement, InvalidParameterCount(usize, usize), SqlInputError { error: Error, msg: String, sql: String, offset: i32, }, InvalidDatabaseIndex(usize),
}
Enum listing possible errors from rusqlite.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SqliteFailure(Error, Option<String>)

An error from an underlying SQLite call.



SqliteSingleThreadedMode

Error reported when attempting to open a connection when SQLite was configured to allow single-threaded use only.



FromSqlConversionFailure(usize, Type, Box<dyn Error + Send + Sync>)

Error when the value of a particular column is requested, but it cannot be converted to the requested Rust type.



IntegralValueOutOfRange(usize, i64)

Error when SQLite gives us an integral value outside the range of the requested type (e.g., trying to get the value 1000 into a u8). The associated usize is the column index, and the associated i64 is the value returned by SQLite.



Utf8Error(usize, Utf8Error)

Error converting a string to UTF-8.



NulError(NulError)

Error converting a string to a C-compatible string because it contained an embedded nul.



InvalidParameterName(String)

Error when using SQL named parameters and passing a parameter name not present in the SQL.



InvalidPath(PathBuf)

Error converting a file path to a string.



ExecuteReturnedResults

Error returned when an execute call returns rows.



QueryReturnedNoRows

Error when a query that was expected to return at least one row (e.g., for query_row) did not return any.



QueryReturnedMoreThanOneRow

Error when a query that was expected to return only one row (e.g., for query_one) did return more than one.



InvalidColumnIndex(usize)

Error when the value of a particular column is requested, but the index is out of range for the statement.



InvalidColumnName(String)

Error when the value of a named column is requested, but no column matches the name for the statement.



InvalidColumnType(usize, String, Type)

Error when the value of a particular column is requested, but the type of the result in that column cannot be converted to the requested Rust type.



StatementChangedRows(usize)

Error when a query that was expected to insert one row did not insert any or insert many.



ToSqlConversionFailure(Box<dyn Error + Send + Sync>)

Error available for the implementors of the ToSql trait.



InvalidQuery

Error when the SQL is not a SELECT, is not read-only.



UnwindingPanic

An unwinding panic occurs in a UDF (user-defined function).



MultipleStatement

Error when the SQL contains multiple statements.



InvalidParameterCount(usize, usize)

Error when the number of bound parameters does not match the number of parameters in the query. The first usize is how many parameters were given, the 2nd is how many were expected.



SqlInputError

Error referencing a specific token in the input SQL

Fields

error: Error

error code

msg: String

error message

sql: String

SQL input

offset: i32

byte offset of the start of invalid token



InvalidDatabaseIndex(usize)

Error when the schema of a particular database is requested, but the index is out of range.

Implementations

Source

impl Error

pub fn sqlite_error(&self) -> Option<&Error>

Returns the underlying SQLite error if this is Error::SqliteFailure.

pub fn sqlite_error_code(&self) -> Option<ErrorCode>

Returns the underlying SQLite error code if this is Error::SqliteFailure.