pub struct LicenseRow {
pub id: Option<i64>,
pub identifier: Option<String>,
pub name: Option<String>,
pub is_deprecated: Option<bool>,
pub is_free_software: Option<bool>,
pub is_open_source: Option<bool>,
}Expand description
SPDX license entry
Fields
id: Option<i64>Unique identifier for the license entry
identifier: Option<String>Unique license identifier (ex., “MIT”)
name: Option<String>License name (ex., “MIT License”)
is_deprecated: Option<bool>Specifies whether the entire license is deprecated
is_free_software: Option<bool>Specifies whether the License is listed as free by the Free Software Foundation (FSF)
is_open_source: Option<bool>Specifies whether the license is approved by the Open Source Initiative (OSI)
Implementations
Sourceimpl LicenseRow
impl LicenseRow
Sourcepub fn init() -> LicenseRowBuilder
pub fn init() -> LicenseRowBuilder
Create an instance of LicenseRow using the builder syntax
Sourceimpl LicenseRow
impl LicenseRow
Sourcepub const TABLE_NAME: &'static str = "licenses"
pub const TABLE_NAME: &'static str = "licenses"
Database table name for this row type.
Sourcepub const FIELDS: &'static [&'static str]
pub const FIELDS: &'static [&'static str]
Field list for build_query! macro documentation purposes.
Sourcepub fn build_select_query(&self, base: &str) -> SelectQuery
pub fn build_select_query(&self, base: &str) -> SelectQuery
Builds a SQL SELECT query with optional WHERE/ORDER BY clauses.