pub struct Database<T>where
T: TableSchemaProvider,{ /* private fields */ }Expand description
Database handle for a given table schema provider type
Implementations
Sourceimpl<T> Database<T>where
T: TableSchemaProvider,
impl<T> Database<T>where
T: TableSchemaProvider,
Sourcepub fn from_path(path: Option<PathBuf>) -> Self
pub fn from_path(path: Option<PathBuf>) -> Self
Create a new database handle from an optional database path override.
Sourcepub fn with_connection<U>(
&self,
callback: impl FnOnce(&Connection) -> ApiResult<U>,
) -> ApiResult<U>
pub fn with_connection<U>( &self, callback: impl FnOnce(&Connection) -> ApiResult<U>, ) -> ApiResult<U>
Executes a callback using the database path configured on this handle.
Sourcepub fn migrate_table(&self, table: impl Into<Table>) -> ApiResult<()>
pub fn migrate_table(&self, table: impl Into<Table>) -> ApiResult<()>
Create one table if it does not exist.
Sourcepub fn delete_expired_before(
&self,
table: impl Into<Table>,
column: &str,
cutoff: &str,
) -> ApiResult<usize>
pub fn delete_expired_before( &self, table: impl Into<Table>, column: &str, cutoff: &str, ) -> ApiResult<usize>
Delete rows where a timestamp/text column is older than a cutoff value.
Sourcepub fn trim_to_recent(
&self,
table: impl Into<Table>,
id_column: &str,
order_column: &str,
limit: usize,
) -> ApiResult<usize>
pub fn trim_to_recent( &self, table: impl Into<Table>, id_column: &str, order_column: &str, limit: usize, ) -> ApiResult<usize>
Keep only the most recent limit rows using an id/order column pair.
Sourcepub fn cleanup_expired_cache(&self) -> ApiResult<usize>
pub fn cleanup_expired_cache(&self) -> ApiResult<usize>
Clean up expired link cache entries and trim validation history.
Sourcepub fn clear_cache(&self) -> ApiResult<usize>
pub fn clear_cache(&self) -> ApiResult<usize>
Clear all cache-related tables.