pub struct DocumentIndex { /* private fields */ }Expand description
Immutable lookup index over a loaded SourceDocument.
Implementations
Sourceimpl DocumentIndex
impl DocumentIndex
Sourcepub fn new(document: SourceDocument) -> Self
pub fn new(document: SourceDocument) -> Self
Index a loaded document without changing its content.
Sourcepub fn document(&self) -> &SourceDocument
pub fn document(&self) -> &SourceDocument
Return the indexed document.
Sourcepub fn position(&self, byte: usize) -> Option<DocumentPosition>
pub fn position(&self, byte: usize) -> Option<DocumentPosition>
Convert a byte offset to one-based physical line and character column.
Sourcepub fn locate(&self, query: &DocumentQuery) -> Option<DocumentPosition>
pub fn locate(&self, query: &DocumentQuery) -> Option<DocumentPosition>
Resolve a query to its one-based physical line and character column
Sourcepub fn excerpt(
&self,
span: &DocumentSpan,
max_prefix: usize,
) -> Option<DocumentExcerpt>
pub fn excerpt( &self, span: &DocumentSpan, max_prefix: usize, ) -> Option<DocumentExcerpt>
Create an excerpt whose highlighted span has at most max_prefix bytes of leading context.
Sourcepub fn resolve(&self, query: &DocumentQuery) -> DocumentMatch
pub fn resolve(&self, query: &DocumentQuery) -> DocumentMatch
Resolve a query only when its physical span can be determined safely.