pub struct DocumentQuery { /* private fields */ }Expand description
Format-neutral criteria for finding a value in a document.
Implementations
Sourceimpl DocumentQuery
impl DocumentQuery
Sourcepub fn with_path(self, path: DocumentPath) -> Self
pub fn with_path(self, path: DocumentPath) -> Self
Add a candidate structured path.
Sourcepub fn with_value(self, value: impl Into<String>) -> Self
pub fn with_value(self, value: impl Into<String>) -> Self
Add an exact decoded value.
Sourcepub fn with_needle(self, needle: impl Into<String>) -> Self
pub fn with_needle(self, needle: impl Into<String>) -> Self
Add a substring to highlight within a matched value or document.