pub enum Executor {
Apptainer,
Docker,
Podman,
Sandbox,
Shell,
Ssh,
Kubernetes,
VirtualMachine,
Other(String),
}Expand description
The “engine” or “execution method” that determines where and how to run (e.g., “execute”) code
Note
At a minimum, choosing an executor also determines level of isolation and security for code execution.
Variants
Apptainer
Simplifies the creation and execution of containers, ensuring software components are encapsulated for portability and reproducibility
Note
Formerly Singularity
Docker
Container engine and ecosystem for building, running, and managing containers
See https://www.docker.com/products/docker-desktop for more information
Podman
Daemonless, open-source container engine for building, running, and managing containers, with a Docker-like command line
Note
Podman is rootless by default
See https://podman.io/ for more information
Sandbox
Secure execution environment that leverages technology other than containerization to achieve isolation
Shell
Local command-line interface that interprets and runs commands for the operating system directly
Ssh
Secure Shell (SSH) protocol for remote command execution
Kubernetes
Portable, extensible, open source platform for managing containerized workloads and services that facilitate both declarative configuration and automation
See https://kubernetes.io/ for more information
VirtualMachine
Software-based computers that run an operating system inside another host system, with stronger isolation than containers
Examples
Other(String)
Custom or unspecified execution method
Implementations
Sourceimpl Executor
impl Executor
Sourcepub fn default_gitlab_runner_config_directory() -> &'static str
pub fn default_gitlab_runner_config_directory() -> &'static str
Returns the default configuration directory on host for GitLab runners based on the operating system.
Sourcepub fn command(&self) -> Option<&str>
pub fn command(&self) -> Option<&str>
Returns the OS binary name used to manage this executor.
Returns "docker", "podman", "apptainer" for container-based
executors, or "gitlab-runner" for all others.
Sourcepub fn gitlab_runner_type(&self) -> &str
pub fn gitlab_runner_type(&self) -> &str
Returns the value passed to gitlab-runner register --executor.