Module opencode

Module opencode 

OpenCode synchronization configuration types

When syncing ACORN models to OpenCode, the sync command creates or updates a custom provider entry that points to the local llama-swap instance. Each model is registered as a keyed entry in the provider’s model map.

Structs

Config
Configuration for synchronizing models into OpenCode