pub enum Component<'a> {
Prefix(PrefixComponent<'a>),
RootDir,
CurDir,
ParentDir,
Normal(&'a OsStr),
}Expand description
A single component of a path.
A Component roughly corresponds to a substring between path separators
(/ or \).
This enum is created by iterating over Components, which in turn is
created by the components method on Path.
Examples
use std::path::{Component, Path};
let path = Path::new("/tmp/foo/bar.txt");
let components = path.components().collect::<Vec<_>>();
assert_eq!(&components, &[
Component::RootDir,
Component::Normal("tmp".as_ref()),
Component::Normal("foo".as_ref()),
Component::Normal("bar.txt".as_ref()),
]);Variants
Prefix(PrefixComponent<'a>)
A Windows path prefix, e.g., C: or \\server\share.
There is a large variety of prefix types, see Prefix’s documentation
for more.
Does not occur on Unix.
RootDir
The root directory component, appears after any prefix and before anything else.
It represents a separator that designates that a path starts from root.
CurDir
A reference to the current directory, i.e., ..
ParentDir
A reference to the parent directory, i.e., ...
Normal(&'a OsStr)
A normal component, e.g., a and b in a/b.
This variant is the most common one, it represents references to files or directories.
Implementations