pub enum Quantization {
Show 13 variants
Q4kM,
Q2k,
Q3kS,
Q3kM,
Q3kL,
Q5kM,
Q6k,
Q8_0,
F8,
F16,
BF16,
IQ4_XS,
Other(String),
}Expand description
Quantization level for a model weight file.
Suffixes follow common GGUF naming:
Kmarks the newer k-quants familyLmeans large, higher-quality size within that familyMmeans medium quality within that familySmeans small, lower-quality size within that family
Q4_K_M is a GGUF quantization format for LLMs used in llama.cpp.
It is often considered the sweet spot between model size and quality:
Q4means 4-bit precision per weightKmeans k-quant, a group-wise quantization schemeMmeans medium, where sensitive tensors are selectively raised to 5-6 bits
IQ is a separate I-quant family that uses an importance matrix for reconstruction.
Variants
Q4kM
Good default balance of quality and size (Q4_K_M), often the sweet spot for GGUF LLMs
Q2k
Lower quality, smallest file size (Q2_K)
Q3kS
Smaller, lower quality (Q3_K_S)
Q3kM
Smaller, lower quality (Q3_K_M)
Q3kL
Smaller, lower quality, larger than Q3_K_M (Q3_K_L)
Q5kM
Better quality, larger file (Q5_K_M)
Q6k
Higher quality, much larger file (Q6_K)
Q8_0
Near full quality, very large file (Q8_0)
F8
8-bit floating-point weights
F16
Full-ish precision, huge file (F16)
BF16
Full-ish precision, huge file (BF16)
IQ4_XS
Importance-aware 4-bit quantization with extra-small size (IQ4_XS)
Other(String)
Catch-all for quantization tags added by upstream catalogs
Implementations
Sourceimpl Quantization
impl Quantization
Sourcepub fn from_gguf_filename(filename: &str) -> Option<Self>
pub fn from_gguf_filename(filename: &str) -> Option<Self>
Detect a quantization tag in a GGUF filename.