Module opencode

Module opencode 

OpenCode configuration data model

See https://opencode.ai/docs/config for more information on OpenCode configuration.

Structs

AgentConfig
Specialized agent configuration
AttachmentConfig
Attachment processing configuration
CommandConfig
Custom command configuration
CompactionConfig
Context compaction behavior
Config
Server and runtime OpenCode configuration
EnterpriseConfig
Enterprise configuration
ExperimentalConfig
Experimental settings that may change without notice
ExperimentalPolicy
Experimental policy statement
FormatterConfig
Formatter command configuration
ImageAttachmentConfig
Image attachment limits
LspServerConfig
Language server process configuration
McpLocalConfig
Local MCP server process configuration
McpOAuthConfig
OAuth configuration for a remote MCP server
McpRemoteConfig
Remote MCP server configuration
ReferenceGit
Git repository reference
ReferenceLocal
Local directory reference
ServerConfig
HTTP server settings
SkillsConfig
Additional skill sources
ToolOutputConfig
Tool output truncation thresholds
WatcherConfig
File watcher configuration

Enums

AgentMode
Agent availability mode
AutoUpdateConfig
Automatic update behavior
BoolOrMap
Value that can be a simple boolean or named configuration map
LayoutConfig
Layout setting (deprecated; no longer configurable)
LogLevel
Runtime log level
LspConfig
Language server configuration entry
McpConfig
Model Context Protocol server configuration
McpOAuthOrFalse
OAuth setting for a remote MCP server
Notify
Update notification mode
PermissionAction
Permission action for a tool or command
PermissionConfig
Global permission configuration
PermissionRuleConfig
Permission rule for a tool or nested command pattern
PluginConfig
Plugin reference
PolicyAction
Experimental policy action
PolicyEffect
Experimental policy effect
ReferenceConfig
Named reference source
ShareConfig
Conversation sharing behavior

Type Aliases

PermissionObjectConfig
Permission rules keyed by tool or command pattern
StringMap
String-keyed map used throughout OpenCode config sections