pub struct ExperimentalConfig {
pub disable_paste_summary: Option<bool>,
pub batch_tool: Option<bool>,
pub open_telemetry: Option<bool>,
pub primary_tools: Option<Vec<String>>,
pub continue_loop_on_deny: Option<bool>,
pub mcp_timeout: Option<u64>,
pub policies: Option<Vec<ExperimentalPolicy>>,
}Expand description
Experimental settings that may change without notice
Fields
disable_paste_summary: Option<bool>Whether paste summaries are disabled
batch_tool: Option<bool>Whether the batch tool is enabled
open_telemetry: Option<bool>Whether OpenTelemetry spans are enabled for AI SDK calls
primary_tools: Option<Vec<String>>Tools that should only be available to primary agents
continue_loop_on_deny: Option<bool>Whether the agent loop continues after a tool call is denied
mcp_timeout: Option<u64>Timeout in milliseconds for MCP requests
policies: Option<Vec<ExperimentalPolicy>>Policy statements for supported resources such as providers