pub struct ModelDetails {Show 20 fields
pub attachment: Option<bool>,
pub benchmarks: Option<Vec<Benchmark>>,
pub family: Option<String>,
pub id: Option<String>,
pub knowledge: Option<String>,
pub last_updated: Option<String>,
pub limit: Option<LimitDetails>,
pub modalities: Option<Modalities>,
pub cost: Option<CostDetails>,
pub name: Option<String>,
pub open_weights: Option<bool>,
pub parameters: Option<i64>,
pub reasoning: Option<bool>,
pub release_date: Option<String>,
pub structured_output: Option<bool>,
pub temperature: Option<bool>,
pub tool_call: Option<bool>,
pub variant: Option<String>,
pub version: Option<SemanticVersion>,
pub weights: Option<Vec<Weight>>,
}Expand description
Describe a language model (LM)
This struct strives to accommodate the wide myriad varieties of language models in the wild.
As such, version is a string instead of a SemanticVersion because versions are attached to models inconsistently.
Fields
attachment: Option<bool>Whether the model supports file attachment
benchmarks: Option<Vec<Benchmark>>Benchmark evaluation results
family: Option<String>Model family that generally describes model architecture (e.g., llama, gemma, qwen, etc.)
id: Option<String>Unique identifier for the model
knowledge: Option<String>Knowledge cutoff date for the model
last_updated: Option<String>Date the model was last updated
limit: Option<LimitDetails>Token limits for the model
modalities: Option<Modalities>Input/output modalities
cost: Option<CostDetails>Pricing information for the model
name: Option<String>String value to override full model string descriptor in cases of ambiguity and inconsistency
open_weights: Option<bool>Indicates whether the model weights are openly available
parameters: Option<i64>Number of parameters (in billions) (e.g., 14 for “14B”)
reasoning: Option<bool>Whether the model supports extended reasoning/thinking
release_date: Option<String>Release date of the model
structured_output: Option<bool>Whether the model supports structured output
temperature: Option<bool>Whether the model supports temperature configuration
tool_call: Option<bool>Whether the model supports tool calling
variant: Option<String>Value that describes niche application of a given model family (e.g., “coder” in “qwen-coder”)
version: Option<SemanticVersion>Version of the model
weights: Option<Vec<Weight>>Download sources for model weights
Implementations
Sourceimpl ModelDetails
impl ModelDetails
Sourcepub fn init() -> ModelDetailsBuilder
pub fn init() -> ModelDetailsBuilder
Create an instance of ModelDetails using the builder syntax