pub struct Memory {
pub amount: f64,
pub unit: MemoryUnit,
}Expand description
Memory amount with explicit unit
Supports string formats like "80GB", "64KB", "512MB", "1TB" and plain number (defaults to GB).
Fields
amount: f64Numeric amount of memory
unit: MemoryUnitUnit of measurement
Implementations
Sourceimpl Memory
impl Memory
Sourcepub fn checked_bytes(&self) -> Option<u64>
pub fn checked_bytes(&self) -> Option<u64>
Convert the memory amount to bytes using binary unit multipliers
Returns None when the amount is not finite, is negative, or exceeds u64
Sourcepub fn can_contain(&self, bytes: u64) -> Option<bool>
pub fn can_contain(&self, bytes: u64) -> Option<bool>
Determine whether a byte count fits in this memory amount