pub struct AccessStatement {
pub text: Option<String>,
pub language: Option<Language>,
}Expand description
Metadata schema block containing an explanation for any access type that is not “open”, with the explanation’s associated properties
Fields
text: Option<String>The text of an access statement that explains any restrictions on access
language: Option<Language>The language of the access statement
Implementations
Sourceimpl AccessStatement
impl AccessStatement
Sourcepub fn builder() -> AccessStatementBuilder
pub fn builder() -> AccessStatementBuilder
Create an instance of AccessStatement using the builder syntax