pub struct MetadataIdentifier {
pub id: Option<String>,
pub schema_uri: Option<String>,
pub owner: Option<Owner>,
pub raid_agency_url: Option<String>,
pub registration_agency: Option<RegistrationAgency>,
pub license: Option<License>,
pub version: Option<u32>,
}Expand description
Metadata schema block containing the RAiD name and associated properties
See https://metadata.raid.org/en/v1.6/core/identifier.html#identifier
Fields
id: Option<String>Unique alphanumeric character string that identifies a Research Activity Identifier (RAiD) name
Format
https://raid.org/prefix/suffix
schema_uri: Option<String>owner: Option<Owner>RAiD owner
raid_agency_url: Option<String>RAiD agency URL
registration_agency: Option<RegistrationAgency>Mtadata schema sub-block declaring the Registration Agency that minted the RAiD
license: Option<License>The licence, or licence waiver, under which the RAiD metadata record associated with this Identifier has been issued
version: Option<u32>Version number of the RAiD
Implementations
Sourceimpl MetadataIdentifier
impl MetadataIdentifier
Sourcepub fn builder() -> MetadataIdentifierBuilder
pub fn builder() -> MetadataIdentifierBuilder
Create an instance of MetadataIdentifier using the builder syntax