pub struct RelatedObject {
pub id: String,
pub schema_uri: Option<String>,
pub related_object_type: RelatedObjectIdentifier,
pub category: Vec<RelatedObjectCategory>,
}Expand description
Metadata schema block containing inputs, outputs, and process documents related to a RAiD plus associated properties
Fields
id: StringPersistent identifier (PID) of related object
The object can be any combination of
- input or resource used by a project or activity
- output or product created by a project or activity
- internal process documentation used within a project or activity
schema_uri: Option<String>URI of the relatedObject identifier schema
Type information of related object
category: Vec<RelatedObjectCategory>Category information of related object
Implementations
Sourceimpl RelatedObject
impl RelatedObject
Sourcepub fn builder() -> RelatedObjectBuilder
pub fn builder() -> RelatedObjectBuilder
Create an instance of RelatedObject using the builder syntax