pub struct TraditionalKnowledgeLabel {
pub id: String,
pub schema_uri: Option<String>,
}Expand description
Metadata schema block containing information about Traditional Knowledge / Biocultural Labels and Notices
Note
Part of “extended” metadata that allows some customization by Registration Agencies
Fields
id: StringIdentifier (URI) linking to a verified source for Traditional Knowledge (TK) or Biocultural (BC) Labels or Notices pertaining to a project or activity
Note
Currently only Local Contexts Hub Projects are allowed as a source for validated TK/BC Labels and Notices.
schema_uri: Option<String>URI of the Traditional Knowledge or Biocultural label identifier schema
Note
Currently only Local Contexts Hub is supported for validated TK/BC Labels and Notices.