pub struct Identifier {
pub kind: PID,
pub value: String,
}Expand description
A persistent identifier type paired with its value.
Fields
kind: PIDPersistent identifier type.
value: StringIdentifier value, either raw or normalized.
Implementations
Sourceimpl Identifier
impl Identifier
Sourceimpl Identifier
impl Identifier
Sourcepub fn init() -> IdentifierBuilder
pub fn init() -> IdentifierBuilder
Create an instance of Identifier using the builder syntax
Sourceimpl Identifier
impl Identifier
Sourcepub fn normalized(&self) -> Option<Self>
pub fn normalized(&self) -> Option<Self>
Normalize this identifier as one supported persistent or URL artifact identifier.
Sourcepub fn identity_key(&self) -> String
pub fn identity_key(&self) -> String
Return this identifier as a normalized exact project identity key.
Sourcepub fn identifier_hash(&self) -> String
pub fn identifier_hash(&self) -> String
Return the deterministic identifier hash used in artifact paths