Check

Struct Check 

pub struct Check {
    pub index: usize,
    pub category: CheckCategory,
    pub locator: Option<String>,
    pub context: Option<String>,
    pub success: bool,
    pub severity: CheckSeverity,
    pub errors: Option<ErrorKind>,
    pub uri: Option<String>,
    pub message: String,
    /* private fields */
}
Data structure for holding the result of a schema validation check

Fields

index: usize

Position of this issue in rendered output

category: CheckCategory

Check category

locator: Option<String>

Unified issue location for checks (prose location or schema path)

context: Option<String>

Textual context of check (e.g., paragraph where prose issues were found)

success: bool

Whether or not the check was successful

severity: CheckSeverity

Severity of the check result

errors: Option<ErrorKind>

Errors and issues found during check

uri: Option<String>

Path of file being validated

message: String

Message related to or description of validation issue (e.g., key name of invalid value, result of validation, etc.)

Implementations

Source

impl Check

pub fn init() -> CheckBuilder

Create an instance of Check using the builder syntax

Source

impl Check

pub fn count_validation_errors(kind: &ValidationErrorsKind) -> usize

Recursively count validation errors from a given ValidationErrorsKind

pub fn is_failure(&self) -> bool

Returns whether this check represents a failure (not successful and severity warrants failure)

pub fn is_visible_at(level: Option<u8>) -> impl Fn(&Check) -> bool

Returns a function that filters checks based on the given log level threshold

pub fn issue_count(&self) -> usize

Returns the number of errors

pub fn report(&self)

Fancy output in contrast with more compressed output of Display impl

pub fn with_context(self, value: String) -> Self

Returns a new LinkCheckResult with the given context

pub fn with_data(self, value: String) -> Self

Returns a new check with renderer data attached.

pub fn with_index(self, value: usize) -> Self

Returns a new LinkCheckResult with the given index

pub fn with_locator(self, value: Option<String>) -> Self

Returns a new LinkCheckResult with the given locator

pub fn with_uri(self, value: Option<String>) -> Self

Returns a new LinkCheckResult with the given URL