pub enum Repository {
Git {
location: Location,
},
GitHub {
location: Location,
},
GitLab {
id: Option<u64>,
location: Location,
},
}Expand description
Git hosting repository data
Variants
Git
Generic Git repository
Note
This repository type should be used for local and offline repositories. Having the associated data be version controlled by Git is recommended, but not required.
GitHub
GitLab
Implementations
Sourceimpl Repository
impl Repository