pub struct Config {Show 37 fields
pub cst: Option<CstRootNode>,
pub path: Option<PathBuf>,
pub agent: Option<StringMap<AgentConfig>>,
pub attachment: Option<AttachmentConfig>,
pub autoshare: Option<bool>,
pub autoupdate: Option<AutoUpdateConfig>,
pub command: Option<StringMap<CommandConfig>>,
pub compaction: Option<CompactionConfig>,
pub default_agent: Option<String>,
pub disabled_providers: Option<Vec<String>>,
pub enabled_providers: Option<Vec<String>>,
pub enterprise: Option<EnterpriseConfig>,
pub experimental: Option<ExperimentalConfig>,
pub formatter: Option<BoolOrMap<FormatterConfig>>,
pub instructions: Option<Vec<String>>,
pub layout: Option<LayoutConfig>,
pub log_level: Option<LogLevel>,
pub lsp: Option<BoolOrMap<LspConfig>>,
pub mcp: Option<StringMap<McpConfig>>,
pub mode: Option<StringMap<AgentConfig>>,
pub model: Option<String>,
pub permission: Option<PermissionConfig>,
pub plugin: Option<Vec<PluginConfig>>,
pub provider: Option<StringMap<Value>>,
pub reference: Option<StringMap<ReferenceConfig>>,
pub references: Option<StringMap<ReferenceConfig>>,
pub schema: Option<String>,
pub server: Option<ServerConfig>,
pub share: Option<ShareConfig>,
pub shell: Option<String>,
pub skills: Option<SkillsConfig>,
pub small_model: Option<String>,
pub snapshot: Option<bool>,
pub tool_output: Option<ToolOutputConfig>,
pub tools: Option<StringMap<bool>>,
pub username: Option<String>,
pub watcher: Option<WatcherConfig>,
}Expand description
Server and runtime OpenCode configuration
Fields
cst: Option<CstRootNode>CST root for JSONC comment-preserving round-trips
path: Option<PathBuf>Source path used to load this configuration
agent: Option<StringMap<AgentConfig>>Named agent configurations
attachment: Option<AttachmentConfig>Attachment processing configuration
Use share instead
Automatic sharing flag
autoupdate: Option<AutoUpdateConfig>Automatic update behavior
command: Option<StringMap<CommandConfig>>Custom command configuration
compaction: Option<CompactionConfig>Context compaction behavior
default_agent: Option<String>Default primary agent used when none is specified
disabled_providers: Option<Vec<String>>Provider IDs that should not be loaded
enabled_providers: Option<Vec<String>>Provider IDs that are allowed when an allowlist is desired
enterprise: Option<EnterpriseConfig>Enterprise configuration
experimental: Option<ExperimentalConfig>Experimental configuration
formatter: Option<BoolOrMap<FormatterConfig>>Formatter enablement or formatter overrides
instructions: Option<Vec<String>>Instruction files or glob patterns to include
layout: Option<LayoutConfig>Remove this field; layout is no longer configurable
Layout option
log_level: Option<LogLevel>Runtime log level
lsp: Option<BoolOrMap<LspConfig>>LSP enablement or LSP server overrides
mcp: Option<StringMap<McpConfig>>MCP server configurations
mode: Option<StringMap<AgentConfig>>Use agent instead
Agent configuration map
model: Option<String>Main model in provider/model format
permission: Option<PermissionConfig>Permission rules for tools and operations
plugin: Option<Vec<PluginConfig>>Plugins loaded from packages or configured with options
provider: Option<StringMap<Value>>Custom provider configuration and model overrides
reference: Option<StringMap<ReferenceConfig>>Use references instead
Named references field
references: Option<StringMap<ReferenceConfig>>Named git or local directory references
schema: Option<String>JSON schema reference for config validation
server: Option<ServerConfig>Server settings for opencode serve and opencode web
Conversation sharing behavior
shell: Option<String>Default shell used for terminal and agent tool calls
skills: Option<SkillsConfig>Additional skill paths or URLs
small_model: Option<String>Small model for lightweight tasks such as title generation
snapshot: Option<bool>Whether filesystem snapshots are recorded for undo and revert
tool_output: Option<ToolOutputConfig>Tool output truncation thresholds
tools: Option<StringMap<bool>>Tool enablement map
username: Option<String>Username displayed in conversations
watcher: Option<WatcherConfig>File watcher settings
Implementations
Sourceimpl Config
impl Config
Sourcepub fn load(path: impl AsRef<Path>) -> Self
pub fn load(path: impl AsRef<Path>) -> Self
Load OpenCode configuration from a path or return an empty configuration.
Sourcepub fn with_provider(self, provider: StringMap<Value>) -> Self
pub fn with_provider(self, provider: StringMap<Value>) -> Self
Replace the configured providers and return the updated configuration.
Sourcepub fn with_model(self, model: String) -> Self
pub fn with_model(self, model: String) -> Self
Set the primary model and return the updated configuration.
Sourcepub fn parse_jsonc(content: &str) -> ApiResult<Self>
pub fn parse_jsonc(content: &str) -> ApiResult<Self>
Parse OpenCode configuration from a JSONC string
Note
Supports JavaScript-style comments (// and /* */) and trailing commas.
Comments are preserved in the CST and restored on write.
Sourcepub fn from_path(path: impl AsRef<Path>) -> ApiResult<Self>
pub fn from_path(path: impl AsRef<Path>) -> ApiResult<Self>
Load OpenCode configuration from a JSONC file path
Sourcepub fn resolve() -> Option<Self>
pub fn resolve() -> Option<Self>
Discover OpenCode configuration in standard locations
Note
Search order is (in order of precedence):
opencode.jsoncin the working directory (per-project)opencode.jsonin the working directory (per-project)~/.config/opencode/opencode.jsonc(user-level)~/.config/opencode/opencode.json(user-level)
Returns the first successfully parsed configuration, or None if not found.