pub trait StringConversion {
// Required methods
fn normalized(&self) -> String;
fn to_cross_platform_path(&self) -> String;
fn file_name_with_parent(&self) -> String;
fn to_absolute_path(&self) -> String;
}Expand description
Trait for augmenting and formatting data for display
Required Methods
Sourcefn normalized(&self) -> String
fn normalized(&self) -> String
Collapse whitespace and convert text to lowercase.
Sourcefn to_cross_platform_path(&self) -> String
fn to_cross_platform_path(&self) -> String
Render a path string using native separators without a Windows extended-length prefix
Sourcefn file_name_with_parent(&self) -> String
fn file_name_with_parent(&self) -> String
Return a string representation of the file_name with its parent folder (or just the folder name if it is a folder)
Sourcefn to_absolute_path(&self) -> String
fn to_absolute_path(&self) -> String
Return a string representation of the absolute path
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".